@@ -116,6 +116,16 @@ sub make_manager_methods
                  " or override the object_class() method in $target_class" : '');
   }
 
+  unless(UNIVERSAL::isa($object_class, 'Rose::DB::Object'))
+  {
+    eval "require $object_class";
+     
+    if($@)
+    {
+      Carp::croak "Could not load object class $object_class - $@";
+    }
+  }
+
   if(!$args{'methods'})
   {
     unless($args{'base_name'})
