@@ -8,20 +8,23 @@ use Rose::DB::Object::MakeMethods::Pg;
 use Rose::DB::Object::Metadata::Column;
 our @ISA = qw(Rose::DB::Object::Metadata::Column);
 
-our $VERSION = '0.01';
+our $VERSION = '0.03';
 
-__PACKAGE__->add_method_maker_argument_names('encrypted_suffix', 'cmp_suffix');
+__PACKAGE__->add_common_method_maker_argument_names('encrypted_suffix', 'cmp_suffix');
 
 Rose::Object::MakeMethods::Generic->make_methods
 (
   { preserve_existing => 1 },
-  scalar => [ __PACKAGE__->method_maker_argument_names ]
+  scalar => [ __PACKAGE__->common_method_maker_argument_names ]
 );
 
-sub type { 'chkpass' }
+foreach my $type (__PACKAGE__->available_method_types)
+{
+  __PACKAGE__->method_maker_class($type => 'Rose::DB::Object::MakeMethods::Pg');
+  __PACKAGE__->method_maker_type($type => 'chkpass');
+}
 
-sub method_maker_class { 'Rose::DB::Object::MakeMethods::Pg' }
-sub method_maker_type  { 'chkpass' }
+sub type { 'chkpass' }
 
 1;
 
@@ -36,7 +39,7 @@ Rose::DB::Object::Metadata::Column::Pg::Chkpass - PostgreSQL CHKPASS column meta
   use Rose::DB::Object::Metadata::Column::Pg::Chkpass;
 
   $col = Rose::DB::Object::Metadata::Column::Pg::Chkpass->new(...);
-  $col->make_method(...);
+  $col->make_methods(...);
   ...
 
 =head1 DESCRIPTION
@@ -45,6 +48,26 @@ Objects of this class store and manipulate metadata for CHKPASS columns in a Pos
 
 This class inherits from L<Rose::DB::Object::Metadata::Column>. Inherited methods that are not overridden will not be documented a second time here.  See the L<Rose::DB::Object::Metadata::Column> documentation for more information.
 
+=head1 METHOD MAP
+
+=over 4
+
+=item C<get_set>
+
+L<Rose::DB::Object::MakeMethods::Pg>, L<chkpass|Rose::DB::Object::MakeMethods::Pg/chkpass>, ...
+
+=item C<get>
+
+L<Rose::DB::Object::MakeMethods::Pg>, L<chkpass|Rose::DB::Object::MakeMethods::Pg/chkpass>, ...
+
+=item C<get_set>
+
+L<Rose::DB::Object::MakeMethods::Pg>, L<chkpass|Rose::DB::Object::MakeMethods::Pg/chkpass>, ...
+
+=back
+
+See the L<Rose::DB::Object::Metadata::Column|Rose::DB::Object::Metadata::Column/"MAKING METHODS"> documentation for an explanation of this method map.
+
 =head1 OBJECT METHODS
 
 =over 4
@@ -57,14 +80,6 @@ Get or set the suffix used to form the name of the comparison method.   See the
 
 Get or set the suffix used to form the name of the accessor method for the encrypted version of the column value.   See the documentation for the C<chkpass> method type in L<Rose::DB::Object::MakeMethods::Pg> for more information.
 
-=item B<method_maker_class>
-
-Returns L<Rose::DB::Object::MakeMethods::Pg>.
-
-=item B<method_maker_type>
-
-Returns C<chkpass>.
-
 =item B<type>
 
 Returns "chkpass".
