@@ -11,7 +11,7 @@ our @ISA = qw(Exporter);
 
 our @EXPORT_OK = qw(build_select build_where_clause);
 
-our $VERSION = '0.051';
+our $VERSION = '0.052';
 
 our $Debug = 0;
 
@@ -51,12 +51,14 @@ sub build_select
   my $sort_by     = delete $args{'sort_by'};
   my $group_by    = delete $args{'group_by'};
   my $limit       = delete $args{'limit'};
+  my $distinct    = delete $args{'distinct'} ? 'DISTINCT ' : '';
   my $select      = $args{'select'};
   my $where_only  = delete $args{'where_only'};
   my $clauses_arg = delete $args{'clauses'};  
   my $pretty      = exists $args{'pretty'} ? $args{'pretty'} : $Debug;
   my $joins       = $args{'joins'};
   my $set         = delete $args{'set'};
+  my $table_map   = delete $args{'table_map'} || {};
 
   $logic = " $logic"  unless($logic eq ',');
 
@@ -181,21 +183,53 @@ sub build_select
         or Carp::confess "No metadata found for class '$obj_class'";
     }
 
-    foreach my $column (@{$columns->{$table}})
+    my $query_only_columns = 0;
+    my $columns = $columns->{$table};
+
+    # No columns to select, but allow them to be queried if we can
+    if(@$columns == 0)
     {
-      my $fq_column    = "$table.$column";
-      my $short_column = "$table_alias.$column";
+      # Don't select these columns, but allow them to participate in the query
+      $query_only_columns = 1; 
+
+      if($obj_meta)
+      {
+        $columns = $obj_meta->column_names;
+      }
+      else # Try to dig out meta object even if query_is_sql
+      {
+        $meta      = $args{'meta'} || {};
+        $obj_class = $classes->{$table};
+        $obj_meta = $meta->{$obj_class} || 
+                      ($obj_class ? $obj_class->meta : undef);
+
+        if($obj_meta)
+        {
+          $columns = $obj_meta->column_names;
+        }
+      }
+    }
+
+    foreach my $column (@$columns)
+    {
+      my $fq_column     = "$table.$column";
+      my $short_column  = "$table_alias.$column";
+      my $unique_column = "${table_alias}_$column";
+      my $rel_column    = $table_map->{$table_alias} ?
+        "$table_map->{$table_alias}.$column" : '';
 
       my $method = $obj_meta ? $obj_meta->column_rw_method_name($column) : undef;
 
-      push(@select_columns, $multi_table ? 
-           "$short_column AS ${table_alias}_$column" : $column);
+      unless($query_only_columns)
+      {
+        push(@select_columns, $multi_table ? 
+             "$short_column AS ${table_alias}_$column" : $column);
+      }
 
-      foreach my $column_arg (map { ($_, "!$_") } ($column, $fq_column, $short_column, 
+      foreach my $column_arg (grep { exists $query{$_} } map { ($_, "!$_") } 
+                              ($column, $fq_column, $short_column, $rel_column, $unique_column, 
                               (defined $method && $method ne $column ? $method : ())))
       {
-        next  unless(exists $query{$column_arg});
-
         $not = (index($column_arg, '!') == 0) ? 'NOT' : '';
 
         # Deflate/format values using prototype objects
@@ -227,11 +261,18 @@ sub build_select
             $val = $tmp{$column_arg};
           }
 
-          if($column_arg eq $column && $column_count{$column} > 1)
+          if($column_arg eq $column && ($column_count{$column} || 0) > 1)
           {
-            Carp::croak "Column '$column' is ambiguous; it appears in ",
-                        "$column_count{$column} tables.  Use a fully-qualified ",
-                        "column name instead (e.g., $fq_column or $short_column)";
+            if($args{'no_ambiguous_columns'})
+            {
+              Carp::croak "Column '$column' is ambiguous; it appears in ",
+                          "$column_count{$column} tables.  Use a fully-qualified ",
+                          "column name instead (e.g., $fq_column or $short_column)";
+            }
+            else # unprefixed columns are considered part of t1
+            {
+              next  unless($table_alias eq 't1');
+            }
           }
 
           my $sql_column = $multi_table ? $short_column : $column;
@@ -343,9 +384,9 @@ sub build_select
         "  $tables->[0]";    
     }
 
-    my $prefix_limit = (defined $limit && $use_prefix_limit) ? $limit : '';
+    my $prefix_limit = (defined $limit && $use_prefix_limit) ? "$limit " : '';
     $select ||= join(",\n", map { "  $_" } @select_columns);
-    $qs = "SELECT $prefix_limit\n$select\nFROM\n$tables_sql\n";
+    $qs = "SELECT $prefix_limit$distinct\n$select\nFROM\n$tables_sql\n";
   }
 
   if($where)
@@ -911,6 +952,10 @@ This indicates the negation of the specified condition.
 
 =back
 
+Un-prefixed column or method names that are ambiguous (i.e., exist in more than one of the tables being queried) are considered to be part of the primary table ("t1").
+
+Finally, in the case of apparently intractable ambiguity, like when a table name is the same as another table's alias, remember that you can always use the "tn_"-prefixed column name aliases, which are unique within a given query.
+
 All of these clauses are joined by C<logic> (default: "AND") in the final query.  Example:
 
     $sql = build_select
