@@ -3,6 +3,7 @@ package MyTest::CDBI::Complex::Product;
 use strict;
 
 use MyTest::CDBI::Complex::Code;
+use MyTest::CDBI::Complex::CodeName;
 use MyTest::CDBI::Complex::Category;
 
 use base 'MyTest::CDBI::Base';
@@ -25,4 +26,6 @@ __PACKAGE__->has_a(published => 'DateTime',
 
 __PACKAGE__->has_a(category_id => 'MyTest::CDBI::Complex::Category');
 
+__PACKAGE__->has_many(code_names => 'MyTest::CDBI::Complex::CodeName');
+
 1;
\ No newline at end of file
