@@ -3,6 +3,7 @@ package MyTest::CDBI::Simple::Product;
 use strict;
 
 use MyTest::CDBI::Simple::Code;
+use MyTest::CDBI::Simple::CodeName;
 use MyTest::CDBI::Simple::Category;
 
 use base 'MyTest::CDBI::Base';
@@ -13,4 +14,6 @@ __PACKAGE__->columns(Essential => qw(category_id date_created fk1 fk2 fk3 id las
 
 __PACKAGE__->has_a(category_id => 'MyTest::CDBI::Simple::Category');
 
+__PACKAGE__->has_many(code_names => 'MyTest::CDBI::Simple::CodeName');
+
 1;
\ No newline at end of file
